# simreq.py

- This library is similar to requests, but in a single file version.


## Installation
- `pip install simreq`


## Example tests

```py
import simreq
c = simreq.get('https://api.jiroawesome.tech')
print(c.status_code)
```


## Special Note
- This project is made for developers, so use it at your own will.
